==> darcs-0.9.12.tar.gz: darcs-0.9.12/manual/labels.pl <==
# LaTeX2HTML 2K.1beta (1.48)
# Associate labels original text with physical files.


$key = q/web_interface/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/merge_thm/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/repository_format/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/darcs-patcher/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/gpl/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/whatsnew/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/token_replace/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/merge_dfn/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/Patch/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/darcs_createrepo/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2K.1beta (1.48)
# labels from external_latex_labels array.


$key = q/web_interface/;
$external_latex_labels{$key} = q|5|; 
$noresave{$key} = "$nosave";

$key = q/merge_thm/;
$external_latex_labels{$key} = q|2|; 
$noresave{$key} = "$nosave";

$key = q/repository_format/;
$external_latex_labels{$key} = q|B|; 
$noresave{$key} = "$nosave";

$key = q/darcs-patcher/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/gpl/;
$external_latex_labels{$key} = q|C|; 
$noresave{$key} = "$nosave";

$key = q/whatsnew/;
$external_latex_labels{$key} = q|4.4|; 
$noresave{$key} = "$nosave";

$key = q/token_replace/;
$external_latex_labels{$key} = q|A.5|; 
$noresave{$key} = "$nosave";

$key = q/merge_dfn/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/Patch/;
$external_latex_labels{$key} = q|A|; 
$noresave{$key} = "$nosave";

$key = q/darcs_createrepo/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

1;

==> darcs_0.9.22.orig.tar.gz: darcs-0.9.22/manual/labels.pl <==
# LaTeX2HTML 2K.1beta (1.48)
# Associate labels original text with physical files.


$key = q/merge_thm/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/configuring/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/author_prefs/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/annotate/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/web_interface/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/defaults/;
$external_labels{$key} = "$URL/" . q|node5.html|; 
$noresave{$key} = "$nosave";

$key = q/unrevert/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/repository_format/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/gpl/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/whatsnew/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/resolution/;
$external_labels{$key} = "$URL/" . q|node6.html|; 
$noresave{$key} = "$nosave";

$key = q/Patch/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/merge_dfn/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/token_replace/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2K.1beta (1.48)
# labels from external_latex_labels array.


$key = q/merge_thm/;
$external_latex_labels{$key} = q|2|; 
$noresave{$key} = "$nosave";

$key = q/configuring/;
$external_latex_labels{$key} = q|4|; 
$noresave{$key} = "$nosave";

$key = q/author_prefs/;
$external_latex_labels{$key} = q|4.1.3|; 
$noresave{$key} = "$nosave";

$key = q/annotate/;
$external_latex_labels{$key} = q|5.27|; 
$noresave{$key} = "$nosave";

$key = q/web_interface/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/defaults/;
$external_latex_labels{$key} = q|4.1.1|; 
$noresave{$key} = "$nosave";

$key = q/unrevert/;
$external_latex_labels{$key} = q|5.17|; 
$noresave{$key} = "$nosave";

$key = q/repository_format/;
$external_latex_labels{$key} = q|B|; 
$noresave{$key} = "$nosave";

$key = q/gpl/;
$external_latex_labels{$key} = q|C|; 
$noresave{$key} = "$nosave";

$key = q/whatsnew/;
$external_latex_labels{$key} = q|5.5|; 
$noresave{$key} = "$nosave";

$key = q/resolution/;
$external_latex_labels{$key} = q|5.1.9|; 
$noresave{$key} = "$nosave";

$key = q/Patch/;
$external_latex_labels{$key} = q|A|; 
$noresave{$key} = "$nosave";

$key = q/merge_dfn/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/token_replace/;
$external_latex_labels{$key} = q|A.5|; 
$noresave{$key} = "$nosave";

1;
